@@ -19,9 +19,14 @@ def waiting_for_opp(room: BattleRoom):
     )
 
 
+DRAW_BY_TURNS = 200
+
+
 class EvalWorker:
     def __init__(
         self,
+        eval_username: str,
+        opponent_username: str,
         battle_format: str,
         team: str,
         eval_actor_fn: Type[Actor] = None,
@@ -30,10 +35,14 @@ class EvalWorker:
         baseline_actor_fn: Type[Actor] = None,
         baseline_actor_args: Sequence[Any] = None,
         baseline_actor_kwargs: Mapping[str, Any] = None,
+        sleep: float = None,
     ):
         self.battle_format = battle_format
         self.team = team
 
+        self.eval_username = eval_username
+        self.opponent_username = opponent_username
+
         self.eval_actor_fn = eval_actor_fn
         self.baseline_actor_fn = baseline_actor_fn
 
@@ -46,6 +55,7 @@ class EvalWorker:
         self.baseline_actor_kwargs = (
             {} if baseline_actor_kwargs is None else baseline_actor_kwargs
         )
+        self.sleep = sleep
 
     def __repr__(self) -> str:
         return f"EvalWorker"
@@ -68,20 +78,25 @@ class EvalWorker:
     async def actor(
         self, player_index: int, actor_fn: Type[Actor], barrier: Barrier
     ) -> Any:
+        if player_index == 0:
+            username = self.eval_username
+        else:
+            username = self.opponent_username
+
         player = await Player.create(username, None, "localhost:8000")
         await player.client.login()
         await barrier.wait()
 
         while True:  # 10 battles each player-player pair
-            await asyncio.sleep(2)
+            if self.sleep:
+                await asyncio.sleep(2)
+
             if player_index == 0:
-                username = self.eval_actor_args[0]
                 await player.client.challenge_user(
                     self.opponent_username, self.battle_format, self.team
                 )
                 actor = actor_fn(*self.eval_actor_args, **self.eval_actor_kwargs)
             else:
-                username = self.baseline_actor_args[0]
                 await player.client.accept_challenge(self.battle_format, self.team)
                 actor = actor_fn(
                     *self.baseline_actor_args, **self.baseline_actor_kwargs
@@ -145,27 +160,38 @@ class EvalWorker:
                 if ended:
                     break
 
-                if (turns_since_last_move > 50 and turn > 100) or turn > 200:
-                    if turns_since_last_move > 50:
-                        print(f"{username}: draw by repetition!")
-                    elif turn > 100:
-                        print(f"{username}: draw by turn > 200!")
+                if turns_since_last_move > 50:
+                    print(f"{username}: forfeit by repetition!")
+
                     await player.client.websocket.send(
-                        player.room.battle_tag + "|" + "/offertie"
+                        player.room.battle_tag + "|" + "/forfeit"
                     )
                     while True:
                         message = await player.client.receive_message()
-                        if "is offering a tie." in message:
-                            await player.client.websocket.send(
-                                player.room.battle_tag + "|" + "/offertie"
-                            )
                         action_required = await player.recieve(message)
                         ended = player.room.get_js_attr("battle?.ended")
                         if ended:
                             break
                     break
 
+                if turn > 200:
+                    print(f"{username}: draw by turn > {DRAW_BY_TURNS}!")
+
+                    await player.client.websocket.send(
+                        player.room.battle_tag + "|" + "/offertie"
+                    )
+                    while True:
+                        message = await player.client.receive_message()
+                        action_required = await player.recieve(message)
+                        if "is offering a tie." in message:
+                            await player.client.websocket.send(
+                                player.room.battle_tag + "|" + "/offertie"
+                            )
+                        ended = player.room.get_js_attr("battle?.ended")
+                        if ended:
+                            break
+                    break
+
             await player.client.leave_battle(player.room.battle_tag)
-            datum = player.room.get_reward()
-            actor.store_reward(player.room, datum["pid"], datum["reward"])
+            actor.post_match(player.room)
             player.reset()
